@@ -318,7 +318,7 @@ shinyApp(
     })
 
     output$thematic_needed <- renderUI({
-      if (bslib:::is_available("thematic")) return(NULL)
+      if (bslib:::is_installed("thematic")) return(NULL)
 
       htmltools::HTML(
         "<span class=\"bg-warning\">&nbsp;!! Install the <a href='https://rstudio.github.io/thematic/'><code>thematic</code></a> package to enable auto-theming of static R plots !!&nbsp;</span>"
